#
# spec file for package vokoscreenNG
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vokoscreenNG
Version:        3.2.0
Release:        bp154.1.65
Summary:        Screencast creator
License:        GPL-2.0-only
Group:          Productivity/Multimedia/Other
URL:            https://github.com/vkohaupt/vokoscreenNG
Source:         https://github.com/vkohaupt/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM - Add AppStream metadata - PR#94
Patch0:         add_appstream_metadata.patch
BuildRequires:  appstream-glib
BuildRequires:  gstreamer-devel >= 1.12.5
BuildRequires:  libqt5-linguist
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core) >= 5.14.0
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)

%if 0%{?sle_version} && 0%{?sle_version} < 150300
Requires:       pulseaudio
%else
Requires:       pulseaudio-daemon
%endif
# Required for vorbis and opus audio
Requires:       gstreamer-plugins-base
# Required for mkv, avi, webm, mp4, vp8 video and flac audio
Requires:       gstreamer-plugins-good
# Required for x265, av1, camera
Requires:       gstreamer-plugins-bad
# Required for x264 and mp3lame
Requires:       gstreamer-plugins-ugly
# Required for x264
Recommends:     gstreamer-plugins-ugly-orig-addon
# Required for openh264
Recommends:     gstreamer-plugins-bad-orig-addon

Provides:       vokoscreen = %{version}
Obsoletes:      vokoscreen < %{version}

%description
vokoscreenNG is a user friendly Open Source screencaster for Linux and Windows.

%prep
%autosetup -p1

%build
cd src
%qmake5
%make_jobs

%install
mkdir -p %{buildroot}/usr/bin/
cp src/%{name} %{buildroot}/usr/bin/
mkdir -p %{buildroot}/usr/share/applications/
cp src/applications/%{name}.desktop %{buildroot}/usr/share/applications/
mkdir -p %{buildroot}/usr/share/pixmaps/
cp src/applications/%{name}.png %{buildroot}/usr/share/pixmaps/
mkdir -p %{buildroot}/usr/share/metainfo/
cp src/applications/vokoscreenNG.appdata.xml %{buildroot}/usr/share/metainfo/

appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.appdata.xml

%files
%doc README.md
%license COPYING
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/metainfo/%{name}.appdata.xml

%changelog
* Tue Mar 29 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.2.0
  * Adjust log file name, add timestamps
  * Only show filename without path in the player window title
  * Improve audio recording when recording from multiple devices on
    PulseAudio
  * Show message in audio tab if no PulseAudio server is found
  * Translation Updates
* Fri Dec 31 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.1.0
  * The Help button has been removed from the title bar of the Player,
    VideoPath and Cisco-License dialog
  * Change system-filedialog to Qt-filedialog
  * Fusion is now the style for all operating systems
  * vokoscreenNG create his own images from all tabs
  * Camera, Magnifier, Showclick and Halo added to the Systray menu
  * Global keyboard shortcuts can be changed
  * Added tooltip for global magnifier shortcut
  * The camera window is now also displayed over a full screen window
  * Countdown: Better look without compositer
  * Countdown: Hide from taskbar
  * Countdown: Added cancel button
  * Better integration "mouse over activates window"
  * Combobox resolution was not deactivated if no camera was found
  * Better hint if no audio recording device was found
  * Option to show mouse clicks
* Wed May 26 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.0.9
  * Add quality slider for VP8 codec
  * Fix setting of audio and video codecs
  * Fix window restoration after minimizing
  * No longer ellipsize drop down menu entries
  * Improve camera picture quality when resizing the window
  * Recording countdown is now shown on the same screen as the
    recorded area
  * Remove AAC codec support
  * Remove x264 codec support
  * Remove VAAPI support
* Thu Feb 25 2021 Antonio Larrosa <alarrosa@suse.com>
- Require the pulseaudio-daemon capability instead of the
  pulseaudio package, so alternative implementations can be used
  (boo#1182730).
* Sun Jan 31 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.0.8
  * Remove unneeded x264 presets
  * Remove predefined recording areas
  * Add h264parse to vaapih264enc
  * Add resolution combobox for camera recording in the dialog window
  * Limit fps to the vertical refresh rate of the screen in Hz
  * Add CPU count to info output
  * Translation updates
- Adapt add_appstream_metadata.patch
* Thu Oct  1 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.0.7
  * Fix magnifier, it is now possible to use on all screens
  * Fix audio device monitoring, now done by pulseaudio
  * Set webcam resolution dynamically from supported resolutions
  * Extend logged videopath information and keep unlimited number
    of logs
* Tue Sep  1 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.0.6
  * Added buffer for audio encoder
  * Added high-4:4:4 profile for x264 encoder
  * Added quality slider for vaapih264
  * Added slice mode, num-slices and max-slice-sice buffers
    for openh264
  * Fixed quality slider values on openh264
* Fri Jul 31 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.0.4
  * fix automatic detection of screen resolution changes
  * switch from adder to audiomixer
  * switch from faac voaacenc
  * remove opus from mov format
- Removed adapt-to-qt-5.15.patch
- Added add_appstream_metadata.patch (boo#1172620)
* Mon Jun  8 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- added adapt-to-qt-5.15.patch
  * upstream fix for Qt 5.15 build failure
* Thu Apr 30 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.0.4
  * added faac audio codec
  * added command line options
  * fix incorrect screen resolution
  * fix folder button being unable to handle spaces in paths
  * fix broken recording when target filename contains spaces
  * fix area selector not supporting multiple monitors
  * fix frame-reset-button not being visible
  * fix visible frame in fps settings
* Tue Mar 31 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.0.3
  * Systray: Better icons for Pause and Continue
  * Frames: Without reset button
  * Camera: If the camera is busy, this will be displayed,
    or is not in combobox
  * Language: added Spanish(Mexico), Slovak (Slovakia)
  * Area: Adapted to Ubuntu GNOME
  * Audio: Hint if no audio devices found
  * Systray: If new version show ballon
  * Camera: Windows and Linux have now the same code base
* Tue Feb 11 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.0.2
  * x264: Codec requires resolution with even values
  * Audio: fix recording with only one channel
  * Webcam: fix image flipped horizontally
* Sat Feb  1 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.0.1
  * Player: Notification if codec or service is missing
  * x264enc: add profile=baseline
  * Select the language for the online help via a combobox
* Tue Dec 31 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.0.0
  * first stable release
  * complete rewrite of vokoscreen, now using gstreamer instead of
    ffmpeg
* Sun Oct 13 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.9.9-beta
* Mon May 20 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.9.8-beta
* Fri May 10 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.9.7-beta
- Made Requirements more specific
* Sat Apr 13 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.9.6-beta
* Tue Feb 19 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Initial build for Version 2.9.5-beta
